=== modified file 'lib/lp/soyuz/scripts/initialize_distroseries.py'
--- lib/lp/soyuz/scripts/initialize_distroseries.py	2011-08-24 11:26:42 +0000
+++ lib/lp/soyuz/scripts/initialize_distroseries.py	2011-09-06 12:10:33 +0000
@@ -3,7 +3,6 @@
 
 """Initialize a distroseries from its parent distroseries."""
 
-
 __metaclass__ = type
 __all__ = [
     'InitializationError',
@@ -33,6 +32,7 @@
     CannotCopy,
     IArchiveSet,
     )
+from lp.soyuz.interfaces.buildpackagejob import COPY_ARCHIVE_SCORE_PENALTY
 from lp.soyuz.interfaces.component import IComponentSet
 from lp.soyuz.interfaces.distributionjob import (
     IDistroSeriesDifferenceJobSource,
@@ -500,12 +500,22 @@
                             check_permissions=False, strict_binaries=False,
                             close_bugs=False, create_dsd_job=False)
                         if self.rebuild:
+                            rebuilds = []
                             for pubrec in sources_published:
-                                pubrec.createMissingBuilds(
+                                builds = pubrec.createMissingBuilds(
                                    list(self.distroseries.architectures))
+                                rebuilds.extend(builds)
+                            self._rescore_rebuilds(rebuilds)
                     except CannotCopy, error:
                         raise InitializationError(error)
 
+    def _rescore_rebuilds(self, builds):
+        """Rescore the passed builds so that they have an appropriately low
+         score.
+        """
+        for build in builds:
+            build.buildqueue_record.lastscore -= COPY_ARCHIVE_SCORE_PENALTY
+
     def _copy_component_section_and_format_selections(self):
         """Copy the section, component and format selections from the parents
         distro series into this one.

=== modified file 'lib/lp/soyuz/scripts/tests/test_initialize_distroseries.py'
--- lib/lp/soyuz/scripts/tests/test_initialize_distroseries.py	2011-08-24 11:41:01 +0000
+++ lib/lp/soyuz/scripts/tests/test_initialize_distroseries.py	2011-09-06 12:10:33 +0000
@@ -797,6 +797,10 @@
         self.assertEqual(self.parent.sourcecount, child.sourcecount)
         self.assertEqual(child.binarycount, 0)
         self.assertEqual(builds.count(), self.parent.sourcecount)
+        for build in builds:
+            # Normally scored at 1760 but 1760 - COPY_ARCHIVE_SCORE_PENALTY
+            # is -840.
+            self.assertEqual(-840, build.api_score)
 
     def test_limit_packagesets_rebuild_and_one_das(self):
         # We can limit the source packages copied, and only builds

